@@ -3,16 +3,17 @@
 
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
-from typing import TYPE_CHECKING, Any, Dict, Collection, List, Optional, Tuple, Union
+from typing import (Any, Collection, Dict, List, Optional,
+                    Tuple, Union)
 
 import pandas as pd
+from mitosheet.code_chunks.step_performers.import_steps.simple_import_code_chunk import generate_read_csv_code
 from mitosheet.errors import get_recent_traceback_as_list
 from mitosheet.mito_analytics import log
 from mitosheet.preprocessing.preprocess_step_performer import \
     PreprocessStepPerformer
 from mitosheet.step_performers.import_steps.simple_import import (
-    generate_read_csv_code, get_valid_dataframe_names,
-    read_csv_get_delimeter_and_encoding)
+    get_valid_dataframe_names, read_csv_get_delimeter_and_encoding)
 from mitosheet.types import StepsManagerType
 
 
